@@ -124,6 +124,17 @@ netmeta <- function(TE, seTE,
     reference.group <- setref(reference.group, labels)
   
   
+  ##
+  ## Check number of subgraphs
+  ##
+  n.subnets <- netconnection(treat1, treat2, studlab)$n.subnets
+  ##
+  if (n.subnets > 1)
+    stop(paste("Network consists of ", n.subnets, " separate sub-networks.\n  ",
+               "Use R function 'netconnection' to identify sub-networks.",
+               sep = ""))
+  
+  
   ##
   ## Check for correct treatment order within comparison
   ##
@@ -274,6 +285,9 @@ netmeta <- function(TE, seTE,
               G.matrix=res.f$G.matrix[o,o],
               H.matrix=res.f$H.matrix[o,o],
               ##
+              Cov.fixed = res.f$Cov,
+              Cov.random = res.r$Cov,
+              ##
               Q.decomp=res.f$Q.decomp,
               ##
               reference.group=reference.group,
